
# Slot: minimum_cardinality


the minimum number of entries for a multivalued slot

URI: [linkml:minimum_cardinality](https://w3id.org/linkml/minimum_cardinality)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](Integer.md)

## Parents

 *  is_a: [value_specification_constant](value_specification_constant.md)

## Children


## Used by

 * [AnonymousSlotExpression](AnonymousSlotExpression.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SlotExpression](SlotExpression.md)
